@@ -8,15 +8,20 @@
 */
 
 #include "UrgCtrl.h"
+#include "GetTicks.h"
 #include <SDL.h>
 
+using namespace beego;
+
 
 int main(int argc, char *argv[]) {
 
-  const char*const device = "/dev/ttyACM0";
+  const char*const device = "/dev/usb/ttyUSB0";
+  //const char*const device = "/dev/ttyACM0";
   //const char*const device = "COM4";
   const long baudrate = 115200;
 
+  size_t first_ticks = GetTicks();
   UrgCtrl urg;
   if (! urg.connect(device, baudrate)) {
     printf("UrgCtrl::connect: %s\n", urg.what());
@@ -27,6 +32,9 @@ int main(int argc, char *argv[]) {
   printf("data_max = %d\n", urg.getMaxDataLength());
   long* data = new long[data_max];
 
+  // ManualCapture  G R}hp邽߁Aŏ̂P̓_~[ǂݏoKv
+  urg.capture(data, data_max);
+
   // f[^\
   int n = urg.capture(data, data_max);
   printf("n = %d\n", n);
@@ -40,5 +48,8 @@ int main(int argc, char *argv[]) {
   delete [] data;
 
   urg.disconnect();
+  size_t last_ticks = GetTicks();
+  printf("spent: %d\n", last_ticks - first_ticks);
+
   return 0;
 }
