@@ -11,11 +11,14 @@
 #include "Delay.h"
 #include <SDL.h>
 
+using namespace beego;
+
 
 int main(int argc, char *argv[]) {
 
   // œnꂽfoCXp
   const char* device = "/dev/ttyACM0";
+  //const char* device = "/dev/usb/ttyUSB0";
   if (argc > 1) {
     device = argv[1];
   }
@@ -40,6 +43,7 @@ int main(int argc, char *argv[]) {
     int n = urg.capture(data, data_max);
     if (n <= 0) {
       // f[^MȂ΁A΂炭ҋ@čēxf[^擾s
+      fprintf(stderr, "\n");
       continue;
     }
     // ʃf[^ƃ^CX^v\
