@@ -12,12 +12,12 @@
 #include "MathUtils.h"
 
 
-void convertToGrid(std::vector<Grid<int> >& points, long data[], size_t size,
-		   const RangeSensorInterface& ranges,
-		   const Position<int>& offset) {
+void beego::convertToGrid(std::vector<Grid<int> >& points, long data[],
+			  size_t size, const RangeSensorInterface* ranges,
+			  const Position<int>& offset) {
 
-  long min_length = ranges.getMinDistance();
-  long max_length = ranges.getMaxDistance();
+  long min_length = ranges->getMinDistance();
+  long max_length = ranges->getMaxDistance();
   Grid<int> p;
   for (size_t i = 0; i < size; ++i) {
     long length = data[i];
@@ -25,7 +25,7 @@ void convertToGrid(std::vector<Grid<int> >& points, long data[], size_t size,
       continue;
     }
     // _̓o^
-    double radian = ranges.index2rad(i) - offset.angle.to_rad();
+    double radian = ranges->index2rad(i) - offset.angle.to_rad();
     p.x = static_cast<int>(length * cos(radian)) + offset.x;
     p.y = static_cast<int>(length * sin(radian)) + offset.y;
 
