@@ -13,6 +13,8 @@
   \todo SearchFilePath Ńt@CL𒲂ׂĂӏu
 */
 
-extern bool existFile(const char* file_path);
+namespace beego {
+  extern bool existFile(const char* file_path);
+};
 
 #endif /* !EXIST_FILE_H */
