@@ -17,6 +17,8 @@
 #include <stdlib.h>
 #include <string>
 
+using namespace beego;
+
 
 /*!
   \brief SdlInit ̓NX
@@ -29,6 +31,9 @@ bool SdlInit::pImpl::initialized = false;
 
 
 SdlInit::SdlInit(void) : pimpl(new pImpl) {
+
+  // !!! double lock ɂׂH
+
   if (pimpl->initialized == false) {
     if (SDL_Init(0) < 0) {
       // OL^
