@@ -26,6 +26,8 @@
 #define DefaultDevice "COM1"
 #endif
 
+using namespace beego;
+
 
 /*!
   \brief kzd@ URG 
@@ -75,14 +77,25 @@ struct UrgCtrl::pImpl {
 	active(false) {
     }
 
+    // !!! ƂɂAׂ
+    // !!! ܂́ASdlInit ܂Ŏ~܂Ă̂H
     ~ThreadArgs(void) {
+      // !!! ܂́AƃbNĂJׂ
+      //LockGuard guard(mutex);
+      // !!! bNA~܂...BfbhbNH
+
+      // !!! ̂ŁAQdɊJĂۂBvΏ
+#if 0
       size_t n = ring_buffer.capacity();
       for (size_t i = 0; i < n; ++i) {
 	data_t* p = ring_buffer.front();
 	delete [] p->data;
+	// !!! ȉ́A܂񂶂Ȃ̂ȁH
+	// !!! ܂A\̂ɃfXgN^`ׂ
 	delete p;
 	ring_buffer.rotate();
       }
+#endif
       SDL_DestroySemaphore(recv_size);
     }
   };
@@ -301,14 +314,14 @@ struct UrgCtrl::pImpl {
     ThreadArgs* info = static_cast<ThreadArgs*>(args);
 
     // f[^̎擾
-    SDL_LockMutex(info->mutex);
+    LockMutex(info->mutex);
     if (info->active) {
 
       // !!! f[^t̏ꍇłA擾KvCĂ
       // !!! f[^肱ڂAH
       // !!! ႤC邪
       // !!! AutoCapture ̏ꍇ́A擾Kv肻
-      SDL_UnlockMutex(info->mutex);
+      UnlockMutex(info->mutex);
 
       // M
       if (! buffer) {
@@ -318,7 +331,7 @@ struct UrgCtrl::pImpl {
       int n = info->scip.recvCaptureData(buffer, info->max_dataLength,
 					 recv_timestamp);
 
-      SDL_LockMutex(info->mutex);
+      LockMutex(info->mutex);
 
       // AutoCapture Ńobt@ĂƂɂ͂P̃f[^̂Ă
       //fprintf(stderr, "ticks: %d\n", GetTicks());
@@ -342,7 +355,7 @@ struct UrgCtrl::pImpl {
 	SDL_SemPost(info->recv_size);
       }
     }
-    SDL_UnlockMutex(info->mutex);
+    UnlockMutex(info->mutex);
 
     delay(info->scan_msec / 10 +1);
     return 0;
@@ -457,6 +470,7 @@ int UrgCtrl::capture(long data[], size_t max_size) {
   int ret = pimpl->capture(data, max_size);
 
   if (! pimpl->urg_handstand) {
+    // f[^̔]
     size_t n = pimpl->thread_args.max_dataLength;
     int front_index = pimpl->scip.getFrontIndex();
     if (front_index < 0) {
@@ -466,7 +480,6 @@ int UrgCtrl::capture(long data[], size_t max_size) {
     if (max_size < n) {
       n = max_size;
     }
-    // !!! FRT 𒆐SɁAO㕝łȂƂlɕύX
     for (size_t i = 0; i < static_cast<size_t>(front_index); ++i) {
       size_t j = (front_index - i) + front_index;
       if (j < n) {
@@ -511,8 +524,18 @@ void UrgCtrl::setDataGroups(size_t groups) {
 
 void UrgCtrl::setCaptureRange(int first_index, int last_index) {
   LockGuard guard(pimpl->mutex);
-  pimpl->first_index = first_index;
-  pimpl->last_index = last_index;
+
+  if (pimpl->urg_handstand) {
+    pimpl->first_index = first_index;
+    pimpl->last_index = last_index;
+
+  } else {
+    size_t front_index = pimpl->scip.getFrontIndex();
+    pimpl->last_index = (front_index - first_index) + front_index;
+    pimpl->first_index = (front_index - last_index) + front_index;
+  }
+
+  pimpl->scip.setCaptureRange(pimpl->first_index, pimpl->last_index);
 }
 
 
